WireMessage

Enum WireMessage 

pub enum WireMessage {
    Control(ControlMessage),
    EncryptedData {
        message_type: u8,
        payload: Vec<u8>,
    },
}
Wrapper for wire messages with type prefix

Variants



Control(ControlMessage)

Control message (JSON)



EncryptedData

Encrypted data (binary)

Fields

message_type: u8
payload: Vec<u8>

Implementations

Source

impl WireMessage

pub fn encode_control(msg: &ControlMessage) -> Vec<u8>

Encode a control message to bytes

pub fn decode_control(data: &[u8]) -> Result<ControlMessage, Error>

Decode a control message from bytes

pub fn encode_encrypted(message_type: u8, encrypted_payload: Vec<u8>) -> Vec<u8>

Encode an encrypted data message to bytes (with type prefix) Format: [message_type: 1 byte][payload]

pub fn encode_encrypted_with_routing( message_type: u8, request_id: &str, encrypted_payload: Vec<u8>, ) -> Vec<u8>

Encode an encrypted data message with routing header Format: [message_type: 1 byte][request_id_len: 1 byte][request_id][encrypted_payload] This allows the relay to route responses without decrypting the payload

pub fn decode_encrypted(data: &[u8]) -> Result<(u8, &[u8]), &'static str>

Decode an encrypted data message from bytes

pub fn decode_encrypted_with_routing( data: &[u8], ) -> Result<(u8, &str, &[u8]), &'static str>

Decode an encrypted data message with routing header Returns (message_type, request_id, encrypted_payload)