pub enum WireMessage {
Control(ControlMessage),
EncryptedData {
message_type: u8,
payload: Vec<u8>,
},
}Expand description
Wrapper for wire messages with type prefix
Variants
Implementations
Sourceimpl WireMessage
impl WireMessage
Sourcepub fn encode_control(msg: &ControlMessage) -> Vec<u8> ⓘ
pub fn encode_control(msg: &ControlMessage) -> Vec<u8> ⓘ
Encode a control message to bytes
Sourcepub fn decode_control(data: &[u8]) -> Result<ControlMessage, Error>
pub fn decode_control(data: &[u8]) -> Result<ControlMessage, Error>
Decode a control message from bytes
Sourcepub fn encode_encrypted(message_type: u8, encrypted_payload: Vec<u8>) -> Vec<u8> ⓘ
pub fn encode_encrypted(message_type: u8, encrypted_payload: Vec<u8>) -> Vec<u8> ⓘ
Encode an encrypted data message to bytes (with type prefix) Format: [message_type: 1 byte][payload]
Sourcepub fn encode_encrypted_with_routing(
message_type: u8,
request_id: &str,
encrypted_payload: Vec<u8>,
) -> Vec<u8> ⓘ
pub fn encode_encrypted_with_routing( message_type: u8, request_id: &str, encrypted_payload: Vec<u8>, ) -> Vec<u8> ⓘ
Encode an encrypted data message with routing header Format: [message_type: 1 byte][request_id_len: 1 byte][request_id][encrypted_payload] This allows the relay to route responses without decrypting the payload